@@ -1,14 +1,13 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-file.c :
  *
- * Copyright (C) 2004,2009-2010 Morten Welinder (terra@gnome.org)
- * Copyright (C) 2004 Yukihiro Nakai  <nakai@gnome.gr.jp>
+ * Copyright (C) 2004,2009-2012 Morten Welinder (terra@gnome.org)
  * Copyright (C) 2003, Red Hat, Inc.
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -470,7 +469,7 @@ go_shell_arg_to_uri (char const *arg)
 
 /**
  * go_basename_from_uri:
- * @uri : The uri
+ * @uri: The uri
  *
  * Decode the final path component.  Returns as UTF-8 encoded suitable
  * for display.
@@ -488,7 +487,7 @@ go_basename_from_uri (char const *uri)
 
 /**
  * go_dirname_from_uri:
- * @uri : target
+ * @uri: target
  * @brief: if TRUE, hide "file://" if present.
  *
  * Decode the all but the final path component.  Returns as UTF-8 encoded
@@ -536,9 +535,9 @@ open_plain_file (char const *path, GError **err)
 
 
 /**
- * go_file_open :
- * @uri : target uri
- * @err : #GError
+ * go_file_open:
+ * @uri: target uri
+ * @err: #GError
  *
  * Try all available methods to open a file or return an error
  * Returns: non-%NULL on success
@@ -908,106 +907,41 @@ go_file_get_date_changed (char const *uri)
 
 /* ------------------------------------------------------------------------- */
 
-/**
- * go_url_decode:
- * @text : constant buffer to decode.
- *
- * Decode the result of go_url_encode.
- *
- * Returns: a decoded string which the caller is responsible for freeing.
- **/
-gchar*
-go_url_decode (gchar const *text)
-{
-	GString *result;
-
-	g_return_val_if_fail (text != NULL, NULL);
-	g_return_val_if_fail (*text != '\0', NULL);
-
-	result = g_string_new (NULL);
-	while (*text) {
-		unsigned char c = *text++;
-		if (c == '%') {
-			if (g_ascii_isxdigit (text[0]) && g_ascii_isxdigit (text[1])) {
-				g_string_append_c (result,
-						   (g_ascii_xdigit_value (text[0]) << 4) |
-						   g_ascii_xdigit_value (text[1]));
-				text += 2;
-			} else {
-				/* Bogus.  */
-				return g_string_free (result, TRUE);
-			}
-		} else
-			g_string_append_c (result, c);
-	}
-
-	return g_string_free (result, FALSE);
-}
-
 /**
  * go_url_encode:
- * @text : The constant text to be encoded
- * @type : 0 : mailto, 1: file or http
+ * @uri_fragment: The uri part to be encoded
+ * @type: 0: mailto, 1: file or http
  *
  * url-encode a string according to RFC 2368.
  *
  * Returns: an encoded string which the caller is responsible for freeing.
  **/
 gchar*
-go_url_encode (gchar const *text, int type)
+go_url_encode (gchar const *uri_fragment, int type)
 {
 	char const *good;
-	static char const hex[16] = "0123456789ABCDEF";
-	GString* result;
 
-	g_return_val_if_fail (text != NULL, NULL);
-	g_return_val_if_fail (*text != '\0', NULL);
+	g_return_val_if_fail (*uri_fragment != '\0', NULL);
 
 	switch (type) {
 	case 0: /* mailto: */
 		good = ".-_@";
 		break;
 	case 1: /* file: or http: */
-		good = "!$&'()*+,-./:=@_";
+		good = G_URI_RESERVED_CHARS_ALLOWED_IN_PATH;
 		break;
 	default:
 		return NULL;
 	}
 
-	result = g_string_new (NULL);
-	while (*text) {
-		unsigned char c = *text++;
-		if (g_ascii_isalnum (c) || strchr (good, c))
-			g_string_append_c (result, c);
-		else {
-			g_string_append_c (result, '%');
-			g_string_append_c (result, hex[c >> 4]);
-			g_string_append_c (result, hex[c & 0xf]);
-		}
-	}
-	return g_string_free (result, FALSE);
-}
-
-/* You probably want go_gtk_url_show instead! */
-GError *
-go_url_show (gchar const *url)
-{
-#ifdef GOFFICE_WITH_GTK
-	GError *error = NULL;
-	gtk_show_uri (NULL, url, GDK_CURRENT_TIME, &error);
-	return error;
-#else
-	GError *error = NULL;
-	g_app_info_launch_default_for_uri (url, NULL, &error);
-	return error;
-#endif
+	return g_uri_escape_string (uri_fragment, good, FALSE);
 }
 
 /**
  * go_url_check_extension
- * @uri     : Uri
- * @std_ext : Standard extension for the content type
- * @new_uri : New uri
+ * @uri: Uri
+ * @std_ext: Standard extension for the content type
+ * @new_uri: New uri
  *
  * Modifies given @uri by adding the extension @std_ext if needed.
  * If no @std_ext is given or @uri already has some extension,
