@@ -1,12 +1,12 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-image.c: Image formats
  *
  * Copyright (C) 2004, 2005 Jody Goldberg (jody@gnome.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -352,21 +352,99 @@ go_image_finalize (GObject *obj)
 	(parent_klass->finalize) (obj);
 }
 
+/* default implementation for unsupported images */
 static void
-go_image_class_init (GObjectClass *klass)
+go_image_draw_fb (GOImage *image, cairo_t *cr)
 {
-	klass->finalize = go_image_finalize;
-	klass->set_property = go_image_set_property;
-	klass->get_property = go_image_get_property;
+	if (image->pixbuf) {
+		cairo_rectangle (cr, 0., 0., image->width, image->height);
+		gdk_cairo_set_source_pixbuf (cr, image->pixbuf, 0, 0);
+		cairo_fill (cr);
+	} else {
+		GdkPixbuf *placeholder = gtk_icon_theme_load_icon
+											(gtk_icon_theme_get_default (),
+											 "unknown_image", 100, 0, NULL);
+		double dx, dy;
+		int n;
+		n = go_fake_floor (image->width / gdk_pixbuf_get_width (placeholder));
+		dx = (image->width - n * gdk_pixbuf_get_width (placeholder)) / 2.;
+		n = go_fake_floor (image->height / gdk_pixbuf_get_height (placeholder));
+		dy = (image->height - n * gdk_pixbuf_get_height (placeholder)) / 2.;
+		cairo_save (cr);
+		cairo_rectangle (cr, 0., 0., image->width, image->height);
+		cairo_clip (cr);
+		cairo_rectangle (cr, -dx, -dy, image->width + dx, image->height + dy);
+		gdk_cairo_set_source_pixbuf (cr, placeholder, 0, 0);
+		cairo_pattern_set_extend (cairo_get_source (cr), CAIRO_EXTEND_REPEAT);
+		cairo_fill (cr);
+		cairo_restore (cr);
+	}
+}
+
+static GdkPixbuf *
+go_image_get_pixbuf_fb (GOImage *image)
+{
+	cairo_surface_t *surface = cairo_image_surface_create (CAIRO_FORMAT_ARGB32,
+		                                                    image->width,
+		                                                    image->height);
+	cairo_t *cr = cairo_create (surface);
+	GdkPixbuf *ret, *placeholder = gtk_icon_theme_load_icon
+		(gtk_icon_theme_get_default (),
+		 "unknown_image", 100, 0, NULL);
+	double dx, dy;
+	int n;
+	n = go_fake_floor (image->width / gdk_pixbuf_get_width (placeholder));
+	dx = (image->width - n * gdk_pixbuf_get_width (placeholder)) / 2.;
+	n = go_fake_floor (image->height / gdk_pixbuf_get_height (placeholder));
+	dy = (image->height - n * gdk_pixbuf_get_height (placeholder)) / 2.;
+	cairo_rectangle (cr, 0., 0., image->width, image->height);
+	cairo_clip (cr);
+	cairo_rectangle (cr, -dx, -dy, image->width + dx, image->height + dy);
+	gdk_cairo_set_source_pixbuf (cr, placeholder, 0, 0);
+	cairo_pattern_set_extend (cairo_get_source (cr), CAIRO_EXTEND_REPEAT);
+	cairo_fill (cr);
+	cairo_destroy (cr);
+	ret = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, image->width, image->height);
+	if (cairo_image_surface_get_stride (surface) != gdk_pixbuf_get_rowstride (ret)) {
+		g_object_unref (ret);
+		ret = NULL;
+	} else
+		go_cairo_convert_data_from_pixbuf (gdk_pixbuf_get_pixels (ret),
+			                               cairo_image_surface_get_data (surface),
+			                               image->width, image->height,
+			                               gdk_pixbuf_get_rowstride (ret));
+	cairo_surface_destroy (surface);
+	return ret;
+}
+
+static GdkPixbuf *
+go_image_get_scaled_pixbuf_fb (GOImage *image, int width, int height)
+{
+	if (image->pixbuf == NULL)
+		image->pixbuf = go_image_get_pixbuf_fb (image);
+	return gdk_pixbuf_scale_simple (image->pixbuf, width, height, GDK_INTERP_BILINEAR);
+}
+
+static void
+go_image_class_init (GOImageClass *klass)
+{
+	GObjectClass *obj_klass = (GObjectClass *) klass;
+	obj_klass->finalize = go_image_finalize;
+	obj_klass->set_property = go_image_set_property;
+	obj_klass->get_property = go_image_get_property;
 	parent_klass = g_type_class_peek_parent (klass);
-	g_object_class_install_property (klass, IMAGE_PROP_WIDTH,
+	g_object_class_install_property (obj_klass, IMAGE_PROP_WIDTH,
 					 g_param_spec_uint ("width", _("Width"),
 							    _("Image width in pixels"),
 							    0, G_MAXUINT16, 0, G_PARAM_READWRITE));
-	g_object_class_install_property (klass, IMAGE_PROP_HEIGHT,
+	g_object_class_install_property (obj_klass, IMAGE_PROP_HEIGHT,
 					 g_param_spec_uint ("height", _("Height"),
 							    _("Image height in pixels"),
 							    0, G_MAXUINT16, 0, G_PARAM_READWRITE));
+
+	klass->draw = go_image_draw_fb;
+	klass->get_pixbuf = go_image_get_pixbuf_fb;
+	klass->get_scaled_pixbuf = go_image_get_scaled_pixbuf_fb;
 }
 
 GSF_CLASS_ABSTRACT (GOImage, go_image,
@@ -390,6 +468,7 @@ go_image_get_thumbnail (GOImage *image)
 		image->thumbnail = go_image_get_scaled_pixbuf (image, GO_THUMBNAIL_SIZE, GO_THUMBNAIL_SIZE);
 	return image->thumbnail;
 }
+
 GdkPixbuf *
 go_image_get_pixbuf (GOImage *image)
 {
@@ -439,9 +518,7 @@ go_image_new_from_file (char const *filename, GError **error)
 	case GO_IMAGE_FORMAT_WMF:
 		return go_emf_new_from_file (filename, error);
 	case GO_IMAGE_FORMAT_EPS:
-#ifdef GOFFICE_WITH_EPS
 		return go_spectre_new_from_file (filename, error);
-#endif
 	case GO_IMAGE_FORMAT_PS: /* we might support ps with libspectre */
 	case GO_IMAGE_FORMAT_PDF:
 	case GO_IMAGE_FORMAT_UNKNOWN:
@@ -477,10 +554,8 @@ go_image_new_from_data (char const *type, guint8 const *data, gsize length, char
 		image = go_svg_new_from_data (data, length, error);
 	} else if (!strcmp (type, "emf") || !strcmp (type, "wmf")) {
 		image = go_emf_new_from_data (data, length, error);
-#ifdef GOFFICE_WITH_EPS
 	} else if (!strcmp (type, "eps")) {
 		image = go_spectre_new_from_data (data, length, error);
-#endif
 	} else {
 		GdkPixbufLoader *loader = gdk_pixbuf_loader_new_with_type (type, error);
 		if (loader) {
@@ -491,18 +566,26 @@ go_image_new_from_data (char const *type, guint8 const *data, gsize length, char
 		}
 	}
 	if (image == NULL) {
-		GtkIconTheme *theme = gtk_icon_theme_get_default ();
+		GdkScreen *screen = gdk_screen_get_default ();
+		GtkIconTheme *theme = screen
+			? gtk_icon_theme_get_default()
+			: gtk_icon_theme_new();
 		GdkPixbuf *placeholder;
+		const char *icon_name;
+
 		if (gtk_icon_theme_has_icon (theme,"unknown_image"))
-			placeholder = gtk_icon_theme_load_icon (theme, "unknown_image", 100, 0, NULL);
+			icon_name = "unknown_image";
 		else if (gtk_icon_theme_has_icon (theme,"unknown"))
-			placeholder = gtk_icon_theme_load_icon (theme, "unknown", 100, 0, NULL);
+			icon_name = "unknown";
 		else
-			placeholder = gtk_icon_theme_load_icon (theme,
-			                                        gtk_icon_theme_get_example_icon_name (theme),
-			                                        100, 0, NULL);
+			icon_name = gtk_icon_theme_get_example_icon_name (theme);
+
+		placeholder = gtk_icon_theme_load_icon (theme, icon_name, 100, 0, NULL);
 		image = go_pixbuf_new_from_pixbuf (placeholder);
 		g_object_unref (placeholder);
+
+		if (!screen)
+			g_object_unref (theme);
 	}
 	if (format)
 		*format = g_strdup (type);
@@ -532,10 +615,12 @@ go_image_type_for_format (char const *format)
 	return 0;
 }
 
-guint8 *
-go_image_get_pixels (GOImage *image)
+guint8 const *
+go_image_get_data (GOImage *image, gsize *length)
 {
 	g_return_val_if_fail (image, NULL);
+	if (length)
+		*length = image->data_length;
 	return image->data;
 }
 
