@@ -1,4 +1,3 @@
-/* vim: set sw=8: -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
  * go-pixbuf.c
  *
@@ -6,8 +5,9 @@
  * Copyright (C) 2011 Jean Brefort (jean.brefort@normalesup.org)
  *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -80,7 +80,7 @@ new_from_data (gconstpointer data, size_t length)
 
 /**
  * go_gdk_pixbuf_new_from_file:
- * @filename : pixbuf filename
+ * @filename: pixbuf filename
  *
  * Utility routine to create pixbufs from file @name in the goffice_icon_dir.
  * As a special case, @filename may have the form "res:<resource name>" in
@@ -293,8 +293,13 @@ go_pixbuf_save (GOImage *image, GsfXMLOut *output)
 	g_return_if_fail (GO_IS_PIXBUF (image));
 	pixbuf = GO_PIXBUF (image);
 	gsf_xml_out_add_int (output, "rowstride", pixbuf->rowstride);
-	gsf_xml_out_add_base64 (output, NULL,
-			image->data, image->height * pixbuf->rowstride);
+	if (!image->data) {
+		image->data = g_new0 (guint8, image->height * pixbuf->rowstride);
+		pixbuf_to_cairo (pixbuf);
+	}
+	gsf_xml_out_add_base64
+		(output, NULL,
+		 image->data, image->height * pixbuf->rowstride);
 }
 
 static void
